#!/usr/bin/python

import sys
import os
import base64

from common import (
    update_client_config, clear_registration, get_service_config,
    get_relation_config)


def _write_certificate(certificate, filename):
    """
    @param certificate Text of the certificate, base64 encoded.
    @param filename Full path to file to write
    """
    with open(filename, "w") as file:
        file.write(base64.b64decode(certificate))


def registration_relation():
    cert_file = "/etc/ssl/certs/landscape_server_ca.crt"
    data = get_relation_config()
    if "ssl-public-key" in data:
        _write_certificate(data["ssl-public-key"], cert_file)
        data["ssl-public-key"] = cert_file
    if "ping-url" in data:
        config_changed(relation_data=data)


def config_changed(relation_data={}):
    """
    @param relation_data: data from the context of a relation, it should
                          match the data in the config
    """
    service_config = get_service_config()
    # Only update client config with service configs that have been set
    service_config = dict(
        (key, value) for key, value in service_config.iteritems()
        if value is not None)
    relation_data.update(service_config)
    if 'account-name' in relation_data:
        sys.exit(update_client_config(relation_data))


HOOKS = {
    "config-changed": config_changed,
    "registration-relation-joined": registration_relation,
    "registration-relation-changed": registration_relation,
    "registration-relation-departed": clear_registration,
    "container-relation-departed": clear_registration,
    "ceph-client-relation-departed": clear_registration}


if __name__ == "__main__":
    hook = os.path.basename(sys.argv[0])
    # If the hook is unsupported, let it raise a KeyError and exit with error.
    HOOKS[hook]()
